@@ -36,6 +36,8 @@ from iw.releaser.packet import increment_changes
 from iw.releaser.packet import create_branches
 from iw.releaser.packet import pypi_upload
 
+from iw.releaser.hook import apply_hooks
+
 from msgfmt import Msgfmt
 
 CONF_FILE = 'iw-releaser.cfg'
@@ -80,25 +82,25 @@ def _get_commands(conf, package_name):
     """Reads a conf file and extract the commands to run"""
     parser = ConfigParser()
     parser.read(conf)
-    
+
     def _validate_command(cmd, package):
-        exprs = [r.strip() for r in 
+        exprs = [r.strip() for r in
                  parser.get(cmd, 'packages').split('\n')]
         run = parser.get(cmd, 'command')
 
         for expr in exprs:
             founded = [r for r in re.findall(expr, package) if
-                       r.strip() != '']  
+                       r.strip() != '']
             if founded != []:
                 return '%s -r %s' % (run, cmd)
         return None
 
-    commands = [cmd.strip() for cmd in 
+    commands = [cmd.strip() for cmd in
                 parser.get('release', 'commands').split('\n')
                 if cmd.strip() != '']
 
     res = [_validate_command(cmd, package_name) for cmd in commands]
- 
+
     return [r for r in res if r is not None]
 
 def make_package_release(auto=False,
@@ -113,9 +115,9 @@ def make_package_release(auto=False,
     package_name = get_name()
 
     # let's see if we have a conf file
-    
+
     places = (join(os.path.expanduser("~"), CONF_FILE),
-              join(os.curdir, CONF_FILE))
+              join(os.getcwd(), CONF_FILE))
 
     commands = []
     for place in places:
@@ -136,7 +138,7 @@ def make_package_release(auto=False,
     if not auto:
         if not release:
             release = yes_no_input(('Do you want to create the release ? '
-                                    'If no, you will just be able to deploy again ' 
+                                    'If no, you will just be able to deploy again '
                                     'the current release'))
     else:
         release = True
@@ -164,6 +166,8 @@ def make_package_release(auto=False,
     if commands != []:
         pypi_upload(commands)
         display('%s released' % new_version)
+        apply_hooks(package_name=package_name,
+                    version=new_version)
 
 class build_mo(Command):
     """Msgfmt"""
@@ -181,7 +185,7 @@ class build_mo(Command):
     def run(self):
         """runner"""
 
-        self.find_locales(os.curdir)
+        self.find_locales(os.getcwd())
 
     def find_locales(self, path):
         """find 'locales' directories and compiles .po files
@@ -202,14 +206,14 @@ class build_mo(Command):
         """
         for language in os.listdir(path):
             lc_path = join(path, language, 'LC_MESSAGES')
-        if os.path.isdir(lc_path):
-            for domain_file in os.listdir(lc_path):
-                if domain_file.endswith('.po'):
-                    file_path = join(lc_path, domain_file)
-                    display("Building .mo for %s" % file_path)
-                    mo_file = join(lc_path, '%s.mo' % domain_file[:-3])
-                    mo_content = Msgfmt(file_path, name=file_path).get()
-                    mo = open(mo_file, 'wb')
-                    mo.write(mo_content)
-                    mo.close()
+            if os.path.isdir(lc_path):
+                for domain_file in os.listdir(lc_path):
+                    if domain_file.endswith('.po'):
+                        file_path = join(lc_path, domain_file)
+                        display("Building .mo for %s" % file_path)
+                        mo_file = join(lc_path, '%s.mo' % domain_file[:-3])
+                        mo_content = Msgfmt(file_path, name=file_path).get()
+                        mo = open(mo_file, 'wb')
+                        mo.write(mo_content)
+                        mo.close()
 
