@@ -16,6 +16,7 @@
 # Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 import os
 import re
+import pkg_resources
 import subprocess
 import tempfile
 import sys
@@ -49,9 +50,20 @@ def get_name():
         return None
     return name[0]
 
-
 def raise_version(version):
     """raises the version"""
+
+    # check version.txt
+    for root, dirs, files in os.walk(os.getcwd()):
+        for dirname in dirs:
+            if os.path.isdir(os.path.join(root, dirname, 'tests')):
+                filename = os.path.join(root, dirname, 'version.txt')
+                if os.path.isfile(filename):
+                    f = open(filename, 'wb')
+                    f.write(version)
+                    f.close()
+
+    # check setup.py
     new_setup = re_version.sub("version = '%s'" % version, _get_setup())
     setup_py = os.path.join(os.getcwd(), 'setup.py') 
     f = open(setup_py, 'wb')
@@ -172,4 +184,3 @@ def pypi_upload(commands):
     for command in commands:
         base.display('Running "%s"' % command)
         _run_setup(*command.split())
-
