@@ -270,8 +270,9 @@ class ProjectTest(unittest.TestCase):
         project = join(os.path.dirname(__file__), 'buildout')
         tarball = join(os.path.dirname(__file__), 'res.tgz') 
         eggs =  project_eggs(join(project, 'buildout.cfg'), tarball)
-        wanted = ['iw.fss (2.7.1)', 'zc.recipe.egg (1.0.0b6)']
-        self.assertEquals(eggs, wanted)
+        
+        self.assert_(eggs[0].startswith('iw.fss'))
+        self.assert_(eggs[-1].startswith('zc.recipe.egg'))
 
         # testing with installation
         folder = tempfile.mkdtemp()
